@@ -6,4 +6,4 @@
 __author__ = """Alec Thomson"""
 __email__ = 'alec.thomson@csiro.au'
 
-from dafits.core import read, write
\ No newline at end of file
+from dafits.core import *
\ No newline at end of file
